@@ -1,5 +1,5 @@
 use cosmwasm_std::StdError;
-use cw0::PaymentError;
+use cw_utils::PaymentError;
 use thiserror::Error;
 
 #[derive(Error, Debug, PartialEq)]
